Module core

Module core 

Core types and functions for the kord crate.

Modules

base
Base types and traits.
chord
A module that contains the Chord struct and related traits.
helpers
Helper functions.
interval
A module for working with intervals.
known_chord
A module for working with known chords.
mode
A module for working with modes.
mode_kind
A module for working with mode kinds.
modifier
A module for working with chord modifiers.
named_pitch
A module for working with named pitches.
notation
A module for working with a unified notation type that can represent a chord, scale, or mode.
note
A module for working with notes.
octave
A module for the octave of a note.
parser
A module for working with the parser for chord symbols.
pitch
A module for the Pitch enum.
scale
A module for working with scales.
scale_kind
A module for working with scale kinds.