Module base

Module base 

Base types and traits.

Structs

PlaybackHandle
A struct for holding the types for a Playable.

Traits

HasDescription
A trait for types that have a description.
HasName
A trait for types that have a computed name.
HasPreciseName
A trait for types that have a computed name.
HasStaticName
A trait for types that have a static name.
Parsable
A trait for types that can be parsed from a string.
Playable
A trait for types that can be “played” via the system’s audio output.

Type Aliases

Err
Global error type.
Res
Global result type.
Void
Global void type.