ScaleCandidate

Enum ScaleCandidate 

pub enum ScaleCandidate {
    Mode {
        kind: ModeKind,
        rank: u8,
        reason: &'static str,
    },
    Scale {
        kind: ScaleKind,
        rank: u8,
        reason: &'static str,
    },
}
Represents a recommended scale or mode for a chord.

Variants



Mode

A mode candidate

Fields

kind: ModeKind

The mode kind

rank: u8

Ranking (1 = most relevant)

reason: &'static str

Reason why this mode fits the chord



Scale

A scale candidate

Fields

kind: ScaleKind

The scale kind

rank: u8

Ranking (1 = most relevant)

reason: &'static str

Reason why this scale fits the chord

Implementations

Source

impl ScaleCandidate

pub fn rank(&self) -> u8

Returns the rank of this candidate

pub fn reason(&self) -> &'static str

Returns the reason for this candidate

pub fn name(&self) -> String

Returns the name of this candidate

pub fn description(&self) -> &'static str

Returns the description of this candidate

pub fn notes(&self, root: Note) -> Vec<Note>

Returns the notes of this candidate rooted at the given note