pub struct IntervalCandidate {
pub kind: IntervalCollectionKind,
pub rank: u8,
pub reason: &'static str,
}Expand description
Represents a scale or mode candidate in static storage format
Fields
kind: IntervalCollectionKindThe kind of interval collection
rank: u8Ranking (1 = most relevant)
reason: &'static strReason why this fits the chord
Implementations
Sourceimpl IntervalCandidate
impl IntervalCandidate
Sourcepub fn to_scale_candidate(&self) -> ScaleCandidate
pub fn to_scale_candidate(&self) -> ScaleCandidate
Converts this interval candidate to a rooted scale candidate