#[repr(u8)]pub enum Extension {
Sus2 = 0,
Sus4 = 1,
Flat11 = 2,
Sharp13 = 3,
Add2 = 4,
Add4 = 5,
Add6 = 6,
Add9 = 7,
Add11 = 8,
Add13 = 9,
}Expand description
An enum representing the extension of a chord.
Extensions are not really “special” in the sense that they do not change how the
chord is interpreted by the system. E.g., an add2 just adds a 2 to the chord,
and the chord is still interpreted as a major chord.
Variants
Sus2 = 0
Sus2 extension.
Sus4 = 1
Sus4 extension.
Flat11 = 2
Flat 11 extension.
Sharp13 = 3
Sharp 13 extension.
Add2 = 4
Add2 extension.
Add4 = 5
Add4 extension.
Add6 = 6
Add6 extension.
Add9 = 7
Add9 extension.
Add11 = 8
Add11 extension.
Add13 = 9
Add13 extension.