#[repr(u8)]pub enum Modifier {
Minor,
Flat5,
Augmented5,
Major7,
Dominant(Degree),
Flat9,
Sharp9,
Sharp11,
Flat13,
Diminished,
}Expand description
An enum representing the modifier of a chord.
Modifiers are “special extensions” that essentially have the capacity to change how the chord is interpreted by the system. E.g., a dominant flat 9 chord is not just a dominant chord with a flat 9 extension, but rather a chord that is represented by an entirely specific scale (half/whole/half diminished).
Variants
Minor
Minor modifier.
Flat5
Flat 5 modifier.
Augmented5
Sharp 5 modifier.
Major7
Major 7 modifier.
Dominant(Degree)
Dominant modifier with degree.
Flat9
Flat 9 modifier.
Sharp9
Sharp 9 modifier.
Sharp11
Sharp 11 modifier.
Flat13
Flat 13 modifier.
Diminished
Diminished modifier.