Module notation

Module notation 

A module for working with a unified notation type that can represent a chord, scale, or mode.

Enums

Notation
A unified notation type that can represent a chord, scale, or mode.