Note

Struct Note 

pub struct Note { /* private fields */ }
A note type.

This is a named pitch with an octave. This type allows for correctly attributing octave changes across an interval from one Note to another.

Implementations

Source

impl Note

pub fn new(pitch: NamedPitch, octave: Octave) -> Self

Creates a new Note from the given NamedPitch and Octave.

pub fn try_from_midi(midi: u8) -> Res<Self>

Attempts to create a Note from a MIDI note number.

Source

impl Note

pub async fn try_from_mic(length_in_seconds: u8) -> Res<Vec<Note>>

Attempts to use the default microphone to listen to audio for the specified time to identify the notes in the recorded audio.

Currently, this does not work with WASM.

pub fn try_from_audio(data: &[f32], length_in_seconds: u8) -> Res<Vec<Note>>

Attempts to use the provided to identify the notes in the audio data.

pub async fn try_from_mic_ml(length_in_seconds: u8) -> Res<Vec<Self>>

Attempts to use the default microphone to listen to audio for the specified time to identify the notes in the recorded audio using ML.

Currently, this does not work with WASM.

pub fn try_from_audio_ml(data: &[f32], length_in_seconds: u8) -> Res<Vec<Self>>

Attempts to use the provided audio data to identify the notes using ML.