Scale

Struct Scale 

pub struct Scale { /* private fields */ }
A scale with a root note.

This combines a root note with a scale kind to produce an actual scale with specific notes.

Implementations

Source

impl Scale

pub fn new(root: Note, kind: ScaleKind) -> Self

Creates a new scale with the given root note and scale kind.

pub fn intervals(&self) -> &'static [Interval]

Returns the intervals of this scale (delegates to the scale kind).

pub fn notes(&self) -> Vec<Note>

Returns the notes of this scale (root + each interval).