Module data

Module data 

Generic data structures and functions for training or inference.

Functions

kord_item_to_sample_tensor
Takes a loaded kord item and converts it to a sample tensor that is ready for classification.
kord_item_to_target_tensor
Takes a loaded kord item and converts it to a folded target tensor that is ready for classification.
normalize
Normalizes a slice in place.
to_zero_mean_unit_variance
Modifies a slice in place to convert values to zero mean and unit variance.