TrainConfig

Struct TrainConfig 

pub struct TrainConfig {
Show 23 fields pub noise_asset_root: String, pub training_sources: Vec<String>, pub validation_sources: Vec<String>, pub destination: String, pub log: String, pub simulation_size: usize, pub simulation_peak_radius: f32, pub simulation_harmonic_decay: f32, pub simulation_frequency_wobble: f32, pub captured_oversample_factor: usize, pub mha_heads: usize, pub dropout: f64, pub trunk_hidden_size: usize, pub model_epochs: usize, pub model_batch_size: usize, pub model_workers: usize, pub model_seed: u64, pub adam_learning_rate: f64, pub adam_weight_decay: f32, pub adam_beta1: f32, pub adam_beta2: f32, pub adam_epsilon: f32, pub no_plots: bool,
}
The training configuration used for all training, inference, and hyper parameter tuning.

Fields

noise_asset_root: String

The source directory for the noise assets used to generate simulated items.

training_sources: Vec<String>

The directories (or the special sim source) that provide training samples. Must contain at least one entry.

validation_sources: Vec<String>

Optional directories (or sim) that provide validation samples. An empty list triggers an 80/20 split of the training pool.

destination: String

The destination directory for the trained model.

log: String

The log directory for training.

simulation_size: usize

Simulation data set size.

simulation_peak_radius: f32

Simulation peak radius.

simulation_harmonic_decay: f32

Simulation harmonic decay.

simulation_frequency_wobble: f32

Simulation frequency wobble.

captured_oversample_factor: usize

The number of times to replicate captured samples when constructing datasets.

mha_heads: usize

The number of Multi Head Attention (MHA) heads.

dropout: f64

The dropout rate applied to attention and trunk layers.

trunk_hidden_size: usize

The hidden size of the model’s MLP trunk.

model_epochs: usize

The number of epochs to train for.

model_batch_size: usize

The number of samples to use per epoch.

model_workers: usize

The number of workers to use for training.

model_seed: u64

The seed used for training.

adam_learning_rate: f64

The Adam optimizer learning rate.

adam_weight_decay: f32

The Adam optimizer weight decay.

adam_beta1: f32

The Adam optimizer beta1.

adam_beta2: f32

The Adam optimizer beta2.

adam_epsilon: f32

The Adam optimizer epsilon.

no_plots: bool

Suppresses the training plots.

Implementations

Source

impl TrainConfig

pub fn new( noise_asset_root: String, training_sources: Vec<String>, validation_sources: Vec<String>, destination: String, log: String, simulation_size: usize, simulation_peak_radius: f32, simulation_harmonic_decay: f32, simulation_frequency_wobble: f32, captured_oversample_factor: usize, mha_heads: usize, dropout: f64, trunk_hidden_size: usize, model_epochs: usize, model_batch_size: usize, model_workers: usize, model_seed: u64, adam_learning_rate: f64, adam_weight_decay: f32, adam_beta1: f32, adam_beta2: f32, adam_epsilon: f32, no_plots: bool, ) -> Self

Create a new instance of the config.