pub struct InferenceResult {
pub pitches: Vec<Pitch>,
pub chords: Vec<Chord>,
pub pitch_deltas: [f32; 12],
}Expand description
Result of ML inference containing all pitch classes and chord candidates.
Fields
pitches: Vec<Pitch>All detected pitch classes.
chords: Vec<Chord>Chord candidates ranked by likelihood.
pitch_deltas: [f32; 12]Delta (probability - threshold) for each of the 12 pitch classes (C through B). Positive values indicate detected pitches, negative values indicate below threshold.