Core types and functions for the kord crate.
Modules
- base
- Base types and traits.
- chord
- A module that contains the
Chordstruct and related traits. - helpers
- Helper functions.
- interval
- A module for working with intervals.
- known_
chord - A module for working with known chords.
- mode
- A module for working with modes.
- mode_
kind - A module for working with mode kinds.
- modifier
- A module for working with chord modifiers.
- named_
pitch - A module for working with named pitches.
- notation
- A module for working with a unified notation type that can represent a chord, scale, or mode.
- note
- A module for working with notes.
- octave
- A module for the octave of a note.
- parser
- A module for working with the parser for chord symbols.
- pitch
- A module for the
Pitchenum. - scale
- A module for working with scales.
- scale_
kind - A module for working with scale kinds.