Base types and traits.
Structs
- Playback
Handle - A struct for holding the types for a
Playable.
Traits
- HasDescription
- A trait for types that have a description.
- HasName
- A trait for types that have a computed name.
- HasPrecise
Name - A trait for types that have a computed name.
- HasStatic
Name - A trait for types that have a static name.
- Parsable
- A trait for types that can be parsed from a string.
- Playable
- A trait for types that can be “played” via the system’s audio output.