pub trait HasName {
// Required method
fn name(&self) -> String;
// Provided method
fn name_ascii(&self) -> String { ... }
}Expand description
A trait for types that have a computed name.
Required Methods
Provided Methods
Sourcefn name_ascii(&self) -> String
fn name_ascii(&self) -> String
Returns the computed name of the type in ASCII.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".