A module for working with chord modifiers.
Enums
- Degree
- An enum representing the degree of a dominant chord.
- Extension
- An enum representing the extension of a chord.
- Modifier
- An enum representing the modifier of a chord.
Traits
- HasIs
Dominant - A trait for types that have a static name.
Functions
- known_
modifier_ sets - Returns the sets of modifiers that have associated known chords.
- likely_
extension_ sets - Returns the sets of extensions that are useful to test when guessing chords.
- one_
off_ modifier_ sets - Returns the sets of modifiers that can be used as one off extensions.