Base types for machine learning.
Re-exports
pub use precision::StorePrecisionSettings;
Modules
- data
- Generic data structures and functions for training or inference.
- helpers
- Module for generic training and inference helpers.
- model
- Model definition for the Kord model.
- precision
- Precision selection for ML pipelines.
Structs
- Kord
Item - A single kord sample.
- Train
Config - The training configuration used for all training, inference, and hyper parameter tuning.
Constants
- DETERMINISTIC_
GUESS_ SIZE - The deterministic guess vector mirrors the MIDI note signature.
- FREQUENCY_
SPACE_ SIZE - The standard frequency space size to use across all ML operations.
- INPUT_
SPACE_ SIZE - The dimensionality of the sample tensor produced by
kord_item_to_sample_tensor. - MEL_
SPACE_ SIZE - The standard mel space size to use across all ML operations.
- NOTE_
SIGNATURE_ SIZE - The number of MIDI-indexed note bins used throughout the pipeline.
- NUM_
CLASSES - Backward-compatible alias for target dimensionality.
- PITCH_
CLASS_ COUNT - The number of pitch classes in a single octave (C through B).
- TARGET_
SPACE_ SIZE - The dimensionality of the target tensor produced by
kord_item_to_target_tensor.