Generic data structures and functions for training or inference.
Functions
- kord_
item_ to_ sample_ tensor - Takes a loaded kord item and converts it to a sample tensor that is ready for classification.
- kord_
item_ to_ target_ tensor - Takes a loaded kord item and converts it to a folded target tensor that is ready for classification.
- normalize
- Normalizes a slice in place.
- to_
zero_ mean_ unit_ variance - Modifies a slice in place to convert values to zero mean and unit variance.